pub type Result<T> = Result<T, SaferRingError>;Expand description
Result type alias for safer-ring operations.
This type alias simplifies function signatures throughout the crate by providing a consistent error type while allowing different success types.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(SaferRingError),
}