BufferType

Enum BufferType 

pub enum BufferType<'buf> {
    None,
    Pinned(Pin<&'buf mut [u8]>),
    Registered(RegisteredBuffer),
    Vectored(Vec<Pin<&'buf mut [u8]>>),
}
Buffer type for operations.

This enum represents the different types of buffers that can be used with operations, supporting both regular pinned buffers and registered buffers.

Variants



None

No buffer (for operations like accept)



Pinned(Pin<&'buf mut [u8]>)

Regular pinned buffer



Registered(RegisteredBuffer)

Registered buffer with the registry



Vectored(Vec<Pin<&'buf mut [u8]>>)

Multiple pinned buffers for vectored I/O