FdType

Enum FdType 

pub enum FdType {
    Raw(RawFd),
    Registered(RegisteredFd),
    Fixed(FixedFile),
}
File descriptor type for operations.

This enum represents the different types of file descriptors that can be used with operations, supporting both regular file descriptors and registered ones.

Variants



Raw(RawFd)

Regular file descriptor



Registered(RegisteredFd)

Registered file descriptor



Fixed(FixedFile)

Fixed file (accessed by index)