pub struct Building;Expand description
Operation is being built and can be configured.
In this state, the operation can have its parameters modified but cannot be submitted to the kernel. This prevents incomplete operations from being submitted accidentally.