pub struct Submitted { /* private fields */ }Expand description
Operation has been submitted and is in flight.
In this state, the operation cannot be modified but can be polled for completion. The operation ID is used to track the operation in the kernel.