FixedFile

Struct FixedFile 

pub struct FixedFile { /* private fields */ }
Fixed file descriptor with optimized kernel access.

Fixed files are pre-registered with the kernel and accessed by index instead of file descriptor, providing better performance for frequently used files.

Implementations

Source

impl FixedFile

pub fn index(&self) -> u32

Get the index of this fixed file.

pub fn raw_fd(&self) -> RawFd

Get the original file descriptor.