pub type ReadFuture<'ring, 'buf> = ReadFuture<'ring, 'buf>;Expand description
Future type for read operations that can be awaited.
Aliased Type
pub struct ReadFuture<'ring, 'buf> { /* private fields */ }pub type ReadFuture<'ring, 'buf> = ReadFuture<'ring, 'buf>;Future type for read operations that can be awaited.
pub struct ReadFuture<'ring, 'buf> { /* private fields */ }