pub type RecvFuture<'ring, 'buf> = RecvFuture<'ring, 'buf>;Expand description
Future type for receive operations that can be awaited.
Aliased Type
pub struct RecvFuture<'ring, 'buf> { /* private fields */ }pub type RecvFuture<'ring, 'buf> = RecvFuture<'ring, 'buf>;Future type for receive operations that can be awaited.
pub struct RecvFuture<'ring, 'buf> { /* private fields */ }