pub type SendFuture<'ring, 'buf> = SendFuture<'ring, 'buf>;Expand description
Future type for send operations that can be awaited.
Aliased Type
pub struct SendFuture<'ring, 'buf> { /* private fields */ }pub type SendFuture<'ring, 'buf> = SendFuture<'ring, 'buf>;Future type for send operations that can be awaited.
pub struct SendFuture<'ring, 'buf> { /* private fields */ }