pub type WriteFuture<'ring, 'buf> = WriteFuture<'ring, 'buf>;Expand description
Future type for write operations that can be awaited.
Aliased Type
pub struct WriteFuture<'ring, 'buf> { /* private fields */ }pub type WriteFuture<'ring, 'buf> = WriteFuture<'ring, 'buf>;Future type for write operations that can be awaited.
pub struct WriteFuture<'ring, 'buf> { /* private fields */ }